@@ -15,9 +15,15 @@
 #' @param service_level  cycle service level requested
 #' @param inventory_cost  inventory cost per unit.
 #' @param ordering_cost  ordering cost for every time an order is made.
-
-#' @import stats
-
+#' @importFrom stats dnorm
+#' @importFrom stats lm
+#' @importFrom stats median
+#' @importFrom stats optim
+#' @importFrom stats optimize
+#' @importFrom stats pnorm
+#' @importFrom stats ppois
+#' @importFrom stats predict
+#' @importFrom stats qnorm
 #' @return a list of two date frames, the simulation and the metrics.
 #' @author "haytham omar  email: <haytham@rescaleanalytics.com>"
 #' @export
@@ -71,6 +77,7 @@ sim_min_Q_pois<- function(demand,lambda,leadtime,service_level,Quantity,
                    recieved=recieved)
   
   data$lost_order<- data$demand -data$sales
+  message('this function is deprecated, kindly use sim_min_Q() instead')
   
   metrics<- data.frame(shortage_cost= sum(data$lost_order,na.rm = TRUE)*shortage_cost,
                        inventory_cost= sum(data$inventory_level,na.rm = TRUE)*inventory_cost,
